@@ -12,6 +12,8 @@
 # limitations under the License.
 
 from django.conf import settings
+from keystoneauth1 import identity
+from keystoneauth1 import session
 from saharaclient.api.base import APIException
 from saharaclient.api.base import Page
 from saharaclient import client as api_client
@@ -26,13 +28,16 @@ from sahara_dashboard import utils as u
 
 # "type" of Sahara service registered in keystone
 SAHARA_SERVICE = 'data-processing'
-# Sahara service_type registered in Juno
-SAHARA_SERVICE_FALLBACK = 'data_processing'
 
-SAHARA_AUTO_IP_ALLOCATION_ENABLED = getattr(
-    settings,
-    'SAHARA_AUTO_IP_ALLOCATION_ENABLED',
-    False)
+try:
+    SAHARA_FLOATING_IP_DISABLED = getattr(
+        settings,
+        'SAHARA_FLOATING_IP_DISABLED')
+except AttributeError:
+    SAHARA_FLOATING_IP_DISABLED = getattr(
+        settings,
+        'SAHARA_AUTO_IP_ALLOCATION_ENABLED',
+        False)
 
 SAHARA_VERIFICATION_DISABLED = getattr(
     settings,
@@ -71,7 +76,7 @@ def safe_call(func, *args, **kwargs):
     """Call a function ignoring Not Found error
 
     This method is supposed to be used only for safe retrieving Sahara
-    objects. If the object is no longer available the None should be
+    objects. If the object is no longer available, then None should be
     returned.
 
     """
@@ -86,21 +91,16 @@ def safe_call(func, *args, **kwargs):
 
 @memoized
 def client(request):
-    try:
-        service_type = SAHARA_SERVICE
-        sahara_url = base.url_for(request, service_type)
-    except exceptions.ServiceCatalogException:
-        # if no endpoint found, fallback to the old service_type
-        service_type = SAHARA_SERVICE_FALLBACK
-        sahara_url = base.url_for(request, service_type)
-
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
+    # TODO(jfreud): pass token directly to client after bug 1747838 resolved
+    auth = identity.Token(auth_url=request.user.endpoint,
+                          token=request.user.token.id,
+                          project_id=request.user.project_id)
+    sess = session.Session(auth=auth)
     return api_client.Client(VERSIONS.get_active_version()["version"],
-                             sahara_url=sahara_url,
-                             service_type=service_type,
-                             project_id=request.user.project_id,
-                             input_auth_token=request.user.token.id,
+                             service_type=SAHARA_SERVICE,
+                             session=sess,
                              insecure=insecure,
                              cacert=cacert)
 
@@ -166,7 +166,8 @@ def nodegroup_template_create(request, name, plugin_name, hadoop_version,
                               use_autoconfig=None,
                               shares=None,
                               is_public=None,
-                              is_protected=None):
+                              is_protected=None,
+                              volume_mount_prefix=None):
     return client(request).node_group_templates.create(
         name=name,
         plugin_name=plugin_name,
@@ -189,7 +190,8 @@ def nodegroup_template_create(request, name, plugin_name, hadoop_version,
         use_autoconfig=use_autoconfig,
         shares=shares,
         is_public=is_public,
-        is_protected=is_protected)
+        is_protected=is_protected,
+        volume_mount_prefix=volume_mount_prefix)
 
 
 def nodegroup_template_list(request, search_opts=None,
@@ -259,6 +261,10 @@ def nodegroup_update_acl_rules(request, nid,
         nid, **prepare_acl_update_dict(is_public, is_protected))
 
 
+def nodegroup_template_export(request, object_id):
+    return client(request).node_group_templates.export(object_id)
+
+
 def cluster_template_create(request, name, plugin_name, hadoop_version,
                             description=None, cluster_configs=None,
                             node_groups=None, anti_affinity=None,
@@ -334,6 +340,10 @@ def cluster_template_update_acl_rules(request, ct_id,
         ct_id, **prepare_acl_update_dict(is_public, is_protected))
 
 
+def cluster_template_export(request, object_id):
+    return client(request).cluster_templates.export(object_id)
+
+
 def cluster_create(request, name, plugin_name, hadoop_version,
                    cluster_template_id=None, default_image_id=None,
                    is_transient=None, description=None, cluster_configs=None,
