@@ -11,12 +11,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from django import http
 from django.template import defaultfilters as filters
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
 from horizon import tables
 from horizon.tabs import base as tabs_base
+from oslo_serialization import jsonutils as json
 
 from sahara_dashboard.api import sahara as saharaclient
 from sahara_dashboard.content.data_processing \
@@ -41,6 +43,15 @@ class CreateNodegroupTemplate(tables.LinkAction):
     icon = "plus"
 
 
+class ImportNodegroupTemplate(tables.LinkAction):
+    name = "import"
+    verbose_name = _("Import Template")
+    url = ("horizon:project:data_processing.clusters:"
+           "import-nodegroup-template-file")
+    classes = ("ajax-modal",)
+    icon = "plus"
+
+
 class ConfigureNodegroupTemplate(tables.LinkAction):
     name = "configure"
     verbose_name = _("Configure Template")
@@ -65,6 +76,22 @@ class EditTemplate(tables.LinkAction):
     classes = ("ajax-modal", )
 
 
+class ExportTemplate(tables.Action):
+    name = "export"
+    verbose_name = _("Export Template")
+    classes = ("ajax-modal", )
+
+    def single(self, data_table, request, object_id):
+        content = json.dumps(saharaclient.nodegroup_template_export(
+            request, object_id)._info)
+        response = http.HttpResponse(content, content_type="application/json")
+        filename = '%s-node-group-template.json' % object_id
+        disposition = 'attachment; filename="%s"' % filename
+        response['Content-Disposition'] = disposition.encode('utf-8')
+        response['Content-Length'] = str(len(response.content))
+        return response
+
+
 class DeleteTemplate(tables.DeleteAction):
     @staticmethod
     def action_present(count):
@@ -131,6 +158,7 @@ class NodegroupTemplatesTable(sahara_table.SaharaPaginateTabbedTable):
         name = "nodegroup_templates"
         verbose_name = _("Node Group Templates")
         table_actions = (CreateNodegroupTemplate,
+                         ImportNodegroupTemplate,
                          ConfigureNodegroupTemplate,
                          DeleteTemplate,
                          NodeGroupTemplatesFilterAction,)
@@ -138,5 +166,6 @@ class NodegroupTemplatesTable(sahara_table.SaharaPaginateTabbedTable):
                               MakeUnProtected)
         row_actions = (EditTemplate,
                        CopyTemplate,
+                       ExportTemplate,
                        DeleteTemplate, MakePublic, MakePrivate, MakeProtected,
                        MakeUnProtected)
