@@ -12,20 +12,20 @@
 # limitations under the License.
 
 import itertools
-import uuid
 
 from django.utils import encoding
 from django.utils import html
 from django.utils import safestring
 from django.utils.translation import ugettext_lazy as _
 from oslo_log import log as logging
+from oslo_utils import uuidutils
 from saharaclient.api import base as api_base
 
 from horizon import exceptions
 from horizon import forms
 from horizon import workflows
 from openstack_dashboard.api import cinder
-from openstack_dashboard.api import network
+from openstack_dashboard.api import neutron
 from openstack_dashboard.dashboards.project.instances \
     import utils as nova_utils
 from openstack_dashboard.dashboards.project.volumes \
@@ -157,8 +157,8 @@ class GeneralConfigAction(workflows.Action):
         plugin, hadoop_version = (
             workflow_helpers.get_plugin_and_hadoop_version(request))
 
-        if not saharaclient.SAHARA_AUTO_IP_ALLOCATION_ENABLED:
-            pools = network.floating_ip_pools_list(request)
+        if not saharaclient.SAHARA_FLOATING_IP_DISABLED:
+            pools = neutron.floating_ip_pools_list(request)
             pool_choices = [(pool.id, pool.name) for pool in pools]
             pool_choices.insert(0, (None, "Do not assign floating IPs"))
 
@@ -280,7 +280,7 @@ class SecurityConfigAction(workflows.Action):
             initial=True)
 
         try:
-            groups = network.security_group_list(request)
+            groups = neutron.security_group_list(request)
         except Exception:
             exceptions.handle(request,
                               _("Unable to get security group list."))
@@ -300,13 +300,23 @@ class SecurityConfigAction(workflows.Action):
 
 
 class CheckboxSelectMultiple(forms.CheckboxSelectMultiple):
+    # TODO(shuyingya): should rewrite this class using the
+    # new method "get_context" when Django version less than 1.11
+    # no longer support.
+    def build_attrs(self, extra_attrs=None, **kwargs):
+        "Helper function for building an attribute dictionary."
+        attrs = dict(self.attrs, **kwargs)
+        if extra_attrs:
+            attrs.update(extra_attrs)
+        return attrs
+
     def render(self, name, value, attrs=None, choices=()):
         if value is None:
             value = []
         has_id = attrs and 'id' in attrs
         final_attrs = self.build_attrs(attrs, name=name)
         output = []
-        initial_service = uuid.uuid4()
+        initial_service = uuidutils.generate_uuid()
         str_values = set([encoding.force_text(v) for v in value])
         for i, (option_value, option_label) in enumerate(
                 itertools.chain(self.choices, choices)):
